.. saenopy documentation master file

Welcome to the SAENOPY Documentation
====================================

SAENOPY a python implementation of the SAENO - Semi-affine Elastic Network Optimizer, originally developed by Julian Steinwachs.

.. toctree::
   :caption: Contents
   :maxdepth: 2

   boundarycondition.ipynb
   regularization.ipynb
   mesh
   material.ipynb
   api

Installation
------------

Saenopy can be installed directly using pip:

    ``pip install saenopy``

Citing Saenopy
--------------

If you use Saenopy for academic research, you are highly encouraged (though not
required) to cite the following papers:

* Steinwachs J., Metzner C., Skodzek K., Lang N., Thievessen I., Mark C., Munster S., Aifantis K. E., Fabry B. (2016)
  `"Three-dimensional force microscopy of cells in biopolymer networks" <http://dx.doi.org/10.1038/nmeth.3685>`_.
  In Nat Methods, volume 13, 2016. doi.org/10.1038/nmeth.3685

* Condor M., Steinwachs J., Mark C., Garcia-Aznar J. M., Fabry B. (2017)
  `"Traction Force Microscopy in 3-Dimensional Extracellular Matrix Networks" <http://dx.doi.org/10.1002/cpcb.24>`_
  In Curr Protoc Cell Biol, volume 75, doi.org/10.1002/cpcb.24

